@@ -22,9 +22,9 @@
 *  along with this program; if not, write to the Free Software              *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA*
  *****************************************************************************/
-#include <klocale.h>
+//#include <klocale.h>
 //#include <kdebug.h>
-//#include <ostream.h>
+
 #include "awardiota.h"
 
 AwardIOTA::AwardIOTA(){
