@@ -32,11 +32,18 @@ const int MODES = 59;
 #ifndef AWARDIOTA_H
 #define AWARDIOTA_H
 //#include <klocale.h>
-#include <qmap.h>
+
+#include <QHash>
+#include <QMap>
 #include "adif.h"
 
 typedef bool iotaStatus[BANDS][MODES]; //0 = worked, 1 = confirmed
-	//static iotaStatus thisIOTAStatus;
+// BM Worked/confirmed
+// 00
+// 01
+// 10
+// 11
+    //static iotaStatus thisIOTAStatus;
 
 class AwardIOTA  {
 /*************************************************************************************
@@ -74,17 +81,17 @@ public:
   int howManyConfirmedBand(const int tband);
   int howManyConfirmedMode(const int tmode);
   void notConfirmed(const QString& tiota, const int tband, const int tmode);
-  void notConfirmedString(const QString& tiota, const QString& tband, const QString& tmode);  
+  void notConfirmedString(const QString& tiota, const QString& tband, const QString& tmode);
   int howManyConfirmed();
 
 private:
-	Adif adif;
-	int iotaCountConfirmed; // How many ZONES confirmed
-	int iotaCountWorked; // How many ZONES worked
-	QString sAux;
-	bool aux;
-	int iAux;
-	iotaStatus thisIOTAStatus;
+    Adif adif;
+    int iotaCountConfirmed; // How many ZONES confirmed
+    int iotaCountWorked; // How many ZONES worked
+    QString sAux;
+    bool aux;
+    int iAux;
+    iotaStatus thisIOTAStatus;
 
   int i, j, k; // just index
 /*  int iotab[ZONES][BANDS]; // -1 Not worked, 0 = worked, 1 = confirmed
@@ -92,13 +99,19 @@ private:
 */
 /*bool iotaW[ZONES];
   bool iotaC[ZONES];
-*/  
+*/
+
+// BM Worked/confirmed
+// 00
+// 01
+// 10
+// 11
+
+    typedef QMap<QString, int	> IOTAMap;  // To map IOTA/Status
+//	typedef QHash<QString, iotaStatus> IOTAMap;  // To map IOTA/Status
+    IOTAMap iotaMap;
+    IOTAMap::Iterator it;
 
-	
-	typedef QMap<QString, iotaStatus> IOTAMap;  // To map IOTA/Status
-	IOTAMap iotaMap; 
-	IOTAMap::Iterator it;
-  
 
 };
 
