@@ -94,6 +94,7 @@
 #include "reference.h"
 #include "cabrillomanagement.h"
 #include "klognetwork.h"
+#include "helpaboutdialog.h"
 // To use the dxmap just uncomment out the define tag below. It will activate all relevant code. Still broken though.
 //#define DXMAP 1
 #ifdef DXMAP
@@ -217,6 +218,7 @@ class Klog : public QMainWindow, private Ui::klog
   Qso getByNumber(const int n);
   void showQso(); // Gets data from the Input part and show in the botton widget
   void toEditQso(); //Puts the QSO data in the edit box
+  void toEditLastQso(); // Sends to toEditQso the last QSO added
   void accept();
 
   private slots:
@@ -242,6 +244,8 @@ class Klog : public QMainWindow, private Ui::klog
     void slotBandChanged ();
     void slotTXFreqChanged(double i);
     void fillDXCCList();	// Fill the KLog tab
+    void slotTXFreqPushButtonClicked();
+    void slotRXFreqPushButtonClicked();
 
 
   private:
@@ -269,8 +273,10 @@ class Klog : public QMainWindow, private Ui::klog
     AwardWAZ waz;
     Awards awards;
     Award award;
+    HelpAboutDialog *helpAboutDialog;
     QStringList awardReferences;	// All the references of the current award to prepare the combobox
     QString DXClusterServerToUse;
+    void keyPressEvent(QKeyEvent *e);
     void processLogLine (const QString& tLogLine); // Process a line of data/qso from adifReadLog
     void clearGUI();
     bool didISave();
@@ -297,6 +303,7 @@ class Klog : public QMainWindow, private Ui::klog
     void showAwardsNumbers(); // Shows how many worked, confirmed, ...
     void clearAwards();
     void showDistancesAndBeam(const int dist, const int beam); // Shows distance and beam
+    void updateFreqFromBandCombo();
 
 // Worked before
     void completeAllQSOsFromLog();
@@ -309,7 +316,8 @@ class Klog : public QMainWindow, private Ui::klog
     QString getNumberString(const int intNumber); //Receives a number a returns a string of a fixed length
     QString getShortNumberString(const int intNumber); //Same that previous but with 3 characters
     int getEntityFromCall(); // Just read the call from the QRZ box and returns the entity number
-
+    
+    int getNumberOfQSLComboBoxFromText(const QString &tqslvia);
     void prepareAwardComboBox(const int tenti);
     QString checkExtension(QString extension); // To check the extension of the file // TNX Kike
 
