@@ -23,8 +23,7 @@
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA  *
 *****************************************************************************/
 
-#include <KDE/KLocale>
-#include <KDE/KIcon>
+
 //#include <QDebug>
 //#include <ostream.h>
 #include "setup.h"
@@ -935,7 +934,7 @@ Setup::slotAddDxClusterPushButtonClicked ()
     {
       QString text = QInputDialog::getText (this,
                         i18n("KLog: Add a DXCluster server"),
-                        i18n("Add the address followed by the :port\nExample: eadx.net:23\nIf no port is specified, 41112 will be used by default.:"),
+                        i18n("Add the address followed by the :port\nExample: dxfun.com:8000\nIf no port is specified, 41112 will be used by default.:"),
                         QLineEdit::Normal, QString::null,
                         &ok);
       if (ok && !text.isEmpty ())
